@@ -17,10 +17,6 @@ class TestNeuroMLLoader(unittest.TestCase):
         root_dir = os.path.dirname(neuroml.__file__)
         test_file_path = os.path.join(root_dir,'test')
         test_file_path = os.path.join(test_file_path,'Purk2M9s.nml')
-        print test_file_path
         f = open(test_file_path,'r')
-        print f
-        #print f.read()
         doc = loaders.NeuroMLLoader.load(test_file_path)
-        print doc
         self.assertEqual(doc.id,'Purk2M9s')
